@@ -4,6 +4,18 @@
 
 satellite-get-tle.pl - Application to retrive TLE data with Astro::SpaceTrack package
 
+=head1 SAMPLE OUTPUT
+
+  GPS BIIA-11 (PRN 24)    
+  1 21552U 91047A   07024.74935505  .00000033  00000-0  10000-3 0  3407
+  2 21552  54.8480 256.1991 0088500 315.8552  43.5043  2.00358418113969
+  GPS BIIA-12 (PRN 25)    
+  1 21890U 92009A   07024.17110927 -.00000036  00000-0  10000-3 0  3146
+  2 21890  54.8611  67.8717 0127244 284.0658  74.5735  2.00378414109321
+  GPS BIIA-14 (PRN 26)    
+  1 22014U 92039A   07024.89979786 -.00000066  00000-0  10000-3 0  3113
+  2 22014  56.8303  15.0910 0175314  46.9379 314.5258  2.00571394100102
+
 =cut
 
 use strict;
@@ -18,13 +30,9 @@ use Astro::SpaceTrack;
 =head2 EXAMPLES
 
   ./satellite-get-tle.pl login password navstar
-
   ./satellite-get-tle.pl login password inmarsat
-
   ./satellite-get-tle.pl login password artemis
-
   ./satellite-get-tle.pl login password galaxy
-
   ./satellite-get-tle.pl login password mtsat
 
 =head2 ACCOUNT
